@@ -1,4 +1,5 @@
 /* Hierarchial argument parsing help output
+   Copyright 2024-2025,2026 Thomas E. Dickey
    Copyright (C) 1995-2003, 2004, 2005 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Written by Miles Bader <miles@gnu.ai.mit.edu>.
@@ -1487,7 +1488,7 @@ argp_doc (const struct argp *argp, const struct argp_state *state,
 
   if (argp->doc)
     {
-      char *vt = strchr (argp->doc, '\v');
+      const char *vt = strchr (argp->doc, '\v');
       if (vt)
 	{
 	  if (post)
