@@ -1,5 +1,6 @@
 /*
  * Blame - An RCS file annotator
+ * Copyright 2024,2026 Thomas E. Dickey
  * Copyright (C) 2004, 2005  Michael Chapman
  *
  * This program is free software; you can redistribute it and/or modify
@@ -1130,7 +1131,7 @@ size_t
 date_sprintf_prefix(time_t date, char *buffer, size_t len) {
 	size_t result;
 	char my_buffer[MAX_FORMAT_DATE + 1];
-	char *format = format_dates;
+	const char *format = format_dates;
 	assert(date >= 0);
 
 	if (format == NULL)
